@@ -21,11 +21,6 @@
 
 #include "oath.h"
 
-/* Prepare for gettext. */
-#define _(x) x
-#define N_(x) x
-#define bindtextdomain(a,b) 0
-
 #define ERR(name, desc) { name, #name, desc }
 
 typedef struct
@@ -36,25 +31,29 @@ typedef struct
 } err_t;
 
 static const err_t errors[] = {
-  ERR (OATH_OK, N_("Successful return")),
-  ERR (OATH_CRYPTO_ERROR, N_("Internal error in crypto functions")),
-  ERR (OATH_INVALID_DIGITS, N_("Unsupported number of OTP digits")),
-  ERR (OATH_PRINTF_ERROR, N_("Error from system printf call")),
-  ERR (OATH_INVALID_HEX, N_("Hex string is invalid")),
-  ERR (OATH_TOO_SMALL_BUFFER, N_("The output buffer is too small")),
-  ERR (OATH_INVALID_OTP, N_("The OTP is not valid")),
-  ERR (OATH_REPLAYED_OTP, N_("The OTP has been replayed")),
-  ERR (OATH_BAD_PASSWORD, N_("The password does not match")),
-  ERR (OATH_INVALID_COUNTER, N_("The counter value is corrupt")),
-  ERR (OATH_INVALID_TIMESTAMP, N_("The timestamp is corrupt")),
-  ERR (OATH_NO_SUCH_FILE, N_("The supplied filename does not exist")),
-  ERR (OATH_UNKNOWN_USER, N_("Cannot find information about user")),
-  ERR (OATH_FILE_SEEK_ERROR, N_("System error when seeking in file")),
-  ERR (OATH_FILE_CREATE_ERROR, N_("System error when creating file")),
-  ERR (OATH_FILE_LOCK_ERROR, N_("System error when locking file")),
-  ERR (OATH_FILE_RENAME_ERROR, N_("System error when renaming file")),
-  ERR (OATH_FILE_UNLINK_ERROR, N_("System error when removing file")),
-  ERR (OATH_TIME_ERROR, N_("System error for time manipulation"))
+  ERR (OATH_OK, "Successful return"),
+  ERR (OATH_CRYPTO_ERROR, "Internal error in crypto functions"),
+  ERR (OATH_INVALID_DIGITS, "Unsupported number of OTP digits"),
+  ERR (OATH_PRINTF_ERROR, "Error from system printf call"),
+  ERR (OATH_INVALID_HEX, "Hex string is invalid"),
+  ERR (OATH_TOO_SMALL_BUFFER, "The output buffer is too small"),
+  ERR (OATH_INVALID_OTP, "The OTP is not valid"),
+  ERR (OATH_REPLAYED_OTP, "The OTP has been replayed"),
+  ERR (OATH_BAD_PASSWORD, "The password does not match"),
+  ERR (OATH_INVALID_COUNTER, "The counter value is corrupt"),
+  ERR (OATH_INVALID_TIMESTAMP, "The timestamp is corrupt"),
+  ERR (OATH_NO_SUCH_FILE, "The supplied filename does not exist"),
+  ERR (OATH_UNKNOWN_USER, "Cannot find information about user"),
+  ERR (OATH_FILE_SEEK_ERROR, "System error when seeking in file"),
+  ERR (OATH_FILE_CREATE_ERROR, "System error when creating file"),
+  ERR (OATH_FILE_LOCK_ERROR, "System error when locking file"),
+  ERR (OATH_FILE_RENAME_ERROR, "System error when renaming file"),
+  ERR (OATH_FILE_UNLINK_ERROR, "System error when removing file"),
+  ERR (OATH_TIME_ERROR, "System error for time manipulation"),
+  ERR (OATH_STRCMP_ERROR, "A strcmp callback returned an error"),
+  ERR (OATH_INVALID_BASE32, "Base32 string is invalid"),
+  ERR (OATH_BASE32_OVERFLOW, "Base32 encoding would overflow"),
+  ERR (OATH_MALLOC_ERROR, "Memory allocation failed")
 };
 
 /**
@@ -77,19 +76,17 @@ static const err_t errors[] = {
 const char *
 oath_strerror (int err)
 {
-  static const char *unknown = N_("Liboath unknown error");
+  static const char *unknown = "Liboath unknown error";
   const char *p;
 
-  bindtextdomain (PACKAGE, LOCALEDIR);
-
   if (-err < 0 || -err >= (int) (sizeof (errors) / sizeof (errors[0])))
-    return _(unknown);
+    return unknown;
 
   p = errors[-err].description;
   if (!p)
     p = unknown;
 
-  return _(p);
+  return p;
 }
 
 
